@@ -381,11 +381,12 @@ def exec_command(exec_id, device_id, cmd, subcmd):
         r"(description\"\:\".*\",\"timer.system|returnValue\"\:\".*\",\"test)",
         ':".*$',
     )
-    timeofExec = getTimeofExecution(
-        response,
-        r"reportPdfUrl\"\:[\s]?\".*\",[\s]?\"executionId",
-        'timestamp\[0\]\=[\d]+',
-    )
+    if("Failed" not in status):
+        timeofExec = getTimeofExecution(
+            response,
+            r"reportPdfUrl\"\:[\s]?\".*\",[\s]?\"executionId",
+            'timestamp\[0\]\=[\d]+',
+        )
     return str(status).replace(",", " "), str(timeofExec)
 
 def create_reservation(resource, resource_id, operation):
@@ -554,8 +555,11 @@ def perform_actions(deviceid_color):
                 try:
                     tempstatus, temp = exec_command(EXEC_ID, device_id, "network.settings", "get")
                     tempstatus = tempstatus.replace("{", "").replace("}", "")
-                    if tempstatus.count(",") == 2:
-                        networkstatus = tempstatus
+                    if tempstatus.count(",") == 2 or tempstatus.count("  ") == 2:
+                        if(tempstatus.count("  ") == 2):
+                            networkstatus = ', e'.join(str(tempstatus).split("  "))
+                        else:
+                            networkstatus = tempstatus
                         status += "NW:OK"
                     else:
                         status += "NW:Failed!"
@@ -725,28 +729,32 @@ def create_summary(df, title, column, name):
     ax1 = pl.subplot(121, aspect="equal", facecolor="#fffffa")
     fig.patch.set_facecolor("lightgoldenrodyellow")
     fig.patch.set_alpha(1)
-    df[column].value_counts().sort_index().plot(
-        kind="pie",
-        y="%",
-        ax=ax1,
-        autopct="%1.1f%%",
-        startangle=30,
-        shadow=False,
-        legend=False,
-        x=df[column].unique,
-        fontsize=7,
-    )
-    pl.ylabel("")
-    # plot table
-    ax2 = pl.subplot(122, facecolor="#fffffa")
-    ax2.patch.set_facecolor("lightgoldenrodyellow")
-    ax2.patch.set_alpha(1)
-    pl.axis("off")
-    tbl = table(ax2, df[column].value_counts(), loc="center")
-    tbl.auto_set_font_size(False)
-    tbl.set_fontsize(8)
-    encoded = fig_to_base64(os.path.join(TEMP_DIR, "results", name + ".png"))
-    summary = '<img src="data:image/png;base64, {}"'.format(encoded.decode("utf-8"))
+    try:
+        df[column].value_counts().sort_index().plot(
+            kind="pie",
+            y="%",
+            ax=ax1,
+            autopct="%1.1f%%",
+            startangle=30,
+            shadow=False,
+            legend=False,
+            x=df[column].unique,
+            fontsize=7,
+        )
+        pl.ylabel("")
+        # plot table
+        ax2 = pl.subplot(122, facecolor="#fffffa")
+        ax2.patch.set_facecolor("lightgoldenrodyellow")
+        ax2.patch.set_alpha(1)
+        pl.axis("off")
+        tbl = table(ax2, df[column].value_counts(), loc="center")
+        tbl.auto_set_font_size(False)
+        tbl.set_fontsize(8)
+        encoded = fig_to_base64(os.path.join(TEMP_DIR, "results", name + ".png"))
+        summary = '<img src="data:image/png;base64, {}"'.format(encoded.decode("utf-8"))
+    except Exception as e:
+        print("API: " + df.url + " throws " + df.msg + ". Raise a support case to get API access for fetching user list/ device list.")
+        summary = '<div style="color: white;">' + df.msg + '. Raise a support case to get API access for fetching user list/ device list.</div><img '
     return summary
 
 
@@ -912,8 +920,9 @@ def prepare_html(user_html, table3, day):
             """
         <html lang="en">
           <head>
-    	  <meta name="viewport" content="width=device-width, initial-scale=1">
-           <meta content="text/html; charset=iso-8859-2" http-equiv="Content-Type">
+            <meta http-equiv="Content-Security-Policy" content="default-src *; img-src * data: http:; script-src 'unsafe-inline' 'unsafe-eval' *; style-src 'unsafe-inline' *">
+    	    <meta name="viewport" content="width=device-width, initial-scale=1">
+            <meta content="text/html; charset=iso-8859-2" http-equiv="Content-Type">
     		<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css">
             <link rel="stylesheet" href="https://www.w3schools.com/w3css/4/w3.css">
     		     <head><title>"""
@@ -1132,7 +1141,7 @@ def prepare_html(user_html, table3, day):
             }}
 
             #myInput, #myInput2, #myInput3 {{
-              background-image: url('http://www.free-icons-download.net/images/mobile-search-icon-94430.png');
+              background-image: url('https://cdn4.iconfinder.com/data/icons/sapphire-storm-1/32/color-web3-18-256.png');
               background-position: 2px 4px;
               background-repeat: no-repeat;
               background-size: 25px 30px;
@@ -1145,8 +1154,7 @@ def prepare_html(user_html, table3, day):
             }}
 
             body {{
-              background-color: #ffffff;
-              background-image: linear-gradient(to right,  #09f, #bfee90, #fff, #fffdd0, #fff, #bfee90, #09f);
+              background-color: black;
               height: 100%;
               background-repeat:  repeat-y;
               background-position: right;
@@ -1538,20 +1546,31 @@ def prepare_html(user_html, table3, day):
                     )
                 )
             else:
-                f.write(
-                    html_string.format(
-                        table=df.to_html(
-                            classes="mystyle", table_id="devicetable", index=False
-                        ),
-                        table2=user_html.to_html(
-                            classes="mystyle",
-                            table_id="usertable",
-                            justify="justify-all",
-                            index=False,
-                        ),
-                        table3="",
+                try:
+                    f.write(
+                        html_string.format(
+                            table=df.to_html(
+                                classes="mystyle", table_id="devicetable", index=False
+                            ),
+                            table2=user_html.to_html(
+                                classes="mystyle",
+                                table_id="usertable",
+                                justify="justify-all",
+                                index=False,
+                            ),
+                            table3="",
+                        )
+                    )
+                except:
+                    f.write(
+                        html_string.format(
+                            table=df.to_html(
+                                classes="mystyle", table_id="devicetable", index=False
+                            ),
+                            table2="",
+                            table3="",
+                        )
                     )
-                )
         webbrowser.open(
             "file://" + os.path.join(TEMP_DIR, "output", "result.html"), new=0
         )
